==> fim_common-0.0.2.tar.gz: lib/custom_widgets/fim_load_image.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:common_utils/common_utils.dart';
import 'package:fim_common/common_utils/fim_image_utils.dart';
import 'package:flutter/material.dart';

/// 图片加载（支持本地与网络图片）
class FimLoadImage extends StatelessWidget {
  const FimLoadImage(this.image,
      {Key key,
      this.width,
      this.height,
      this.fit: BoxFit.cover,
      this.format: "png",
      this.holderImg: "none"})
      : super(key: key);

  final String image;
  final double width;
  final double height;
  final BoxFit fit;
  final String format;
  final String holderImg;

  @override
  Widget build(BuildContext context) {
    if (TextUtil.isEmpty(image) || image == "null") {
      return FimLoadAssetImage(
        holderImg,
        height: height,
        width: width,
        fit: fit,
        format: format,
      );
    } else {
      if (image.startsWith("http")) {
        return CachedNetworkImage(
          imageUrl: image,
          placeholder: (context, url) {
            return FimLoadAssetImage(holderImg,
                height: height, width: width, fit: fit);
          },
          errorWidget: (context, url, error) {
            return FimLoadAssetImage(holderImg,
                height: height, width: width, fit: fit);
          },
          width: width,
          height: height,
          fit: fit,
        );
      } else {
        return FimLoadAssetImage(
          image,
          height: height,
          width: width,
          fit: fit,
          format: format,
        );
      }
    }
  }
}

/// 加载本地资源图片
class FimLoadAssetImage extends StatelessWidget {
  const FimLoadAssetImage(this.image,
      {Key key,
      this.width,
      this.height,
      this.fit,
      this.format: 'png',
      this.color})
      : super(key: key);

  final String image;
  final double width;
  final double height;
  final BoxFit fit;
  final String format;
  final Color color;

  @override
  Widget build(BuildContext context) {
    return Image.asset(
      FimImageUtils.getImgPath(image, format: format),
      height: height,
      width: width,
      fit: fit,
      color: color,
    );
  }
}

==> fim_common-0.0.3.tar.gz: lib/custom_widgets/fim_load_image.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:common_utils/common_utils.dart';
import 'package:fim_common/common_utils/fim_image_utils.dart';
import 'package:flutter/material.dart';

/// 图片加载（支持本地与网络图片）
class FimLoadImage extends StatelessWidget {
  const FimLoadImage(this.image,
      {Key key,
      this.width,
      this.height,
      this.fit: BoxFit.cover,
      this.format: "png",
      this.holderImg: "images/none"})
      : super(key: key);

  final String image;
  final double width;
  final double height;
  final BoxFit fit;
  final String format;
  final String holderImg;

  @override
  Widget build(BuildContext context) {
    if (TextUtil.isEmpty(image) || image == "null") {
      return FimLoadAssetImage(
        holderImg,
        height: height,
        width: width,
        fit: fit,
        format: format,
      );
    } else {
      if (image.startsWith("http")) {
        return CachedNetworkImage(
          imageUrl: image,
          placeholder: (context, url) {
            return FimLoadAssetImage(holderImg,
                height: height, width: width, fit: fit);
          },
          errorWidget: (context, url, error) {
            return FimLoadAssetImage(holderImg,
                height: height, width: width, fit: fit);
          },
          width: width,
          height: height,
          fit: fit,
        );
      } else {
        return FimLoadAssetImage(
          image,
          height: height,
          width: width,
          fit: fit,
          format: format,
        );
      }
    }
  }
}

/// 加载本地资源图片
class FimLoadAssetImage extends StatelessWidget {
  const FimLoadAssetImage(this.image,
      {Key key,
      this.width,
      this.height,
      this.fit,
      this.format: 'png',
      this.color})
      : super(key: key);

  final String image;
  final double width;
  final double height;
  final BoxFit fit;
  final String format;
  final Color color;

  @override
  Widget build(BuildContext context) {
    return Image.asset(
      FimImageUtils.getImgPath(image, format: format),
      height: height,
      width: width,
      fit: fit,
      color: color,
    );
  }
}
